@@ -895,6 +895,100 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('catalog/template_file').with_value('/some/template_file') }
   end
 
+  describe 'when using credentials' do
+    describe 'when enabling credential_setup' do
+      let :params do
+        default_params.merge({
+          'enable_credential_setup'   => true,
+          'credential_key_repository' => '/etc/keystone/credential-keys',
+        })
+      end
+      it { is_expected.to contain_file(params['credential_key_repository']).with(
+        :ensure => 'directory',
+        :owner  => params['keystone_user'],
+        :group  => params['keystone_group'],
+      ) }
+
+      it { is_expected.to contain_exec('keystone-manage credential_setup').with(
+        :command => "keystone-manage credential_setup --keystone-user #{params['keystone_user']} --keystone-group #{params['keystone_group']}",
+        :user    => params['keystone_user'],
+        :creates => '/etc/keystone/credential-keys/0',
+        :require => 'File[/etc/keystone/credential-keys]',
+      ) }
+      it { is_expected.to contain_keystone_config('credential/key_repository').with_value('/etc/keystone/credential-keys')}
+    end
+
+    describe 'when overriding the credential key directory' do
+      let :params do
+        default_params.merge({
+          'enable_credential_setup'   => true,
+          'credential_key_repository' => '/var/lib/credential-keys',
+        })
+      end
+      it { is_expected.to contain_exec('keystone-manage credential_setup').with(
+        :creates => '/var/lib/credential-keys/0'
+      ) }
+    end
+
+    describe 'when overriding the keystone group and user' do
+      let :params do
+        default_params.merge({
+          'enable_credential_setup' => true,
+          'keystone_user'           => 'test_user',
+          'keystone_group'          => 'test_group',
+        })
+      end
+
+      it { is_expected.to contain_exec('keystone-manage credential_setup').with(
+        :command => "keystone-manage credential_setup --keystone-user #{params['keystone_user']} --keystone-group #{params['keystone_group']}",
+        :user    => params['keystone_user'],
+        :creates => '/etc/keystone/credential-keys/0',
+        :require => 'File[/etc/keystone/credential-keys]',
+      ) }
+    end
+
+    describe 'when setting credential_keys parameter' do
+      let :params do
+        default_params.merge({
+          'enable_credential_setup' => true,
+          'credential_keys' => {
+            '/etc/keystone/credential-keys/0' => {
+              'content' => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
+            },
+            '/etc/keystone/credential-keys/1' => {
+              'content' => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
+            },
+          }
+        })
+      end
+
+      it { is_expected.to_not contain_exec('keystone-manage credential_setup') }
+      it { is_expected.to contain_file('/etc/keystone/credential-keys/0').with(
+        'content'   => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
+        'owner'     => 'keystone',
+        'owner'     => 'keystone',
+        'subscribe' => 'Anchor[keystone::install::end]',
+      )}
+      it { is_expected.to contain_file('/etc/keystone/credential-keys/1').with(
+        'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
+        'owner'     => 'keystone',
+        'owner'     => 'keystone',
+        'subscribe' => 'Anchor[keystone::install::end]',
+      )}
+    end
+
+    describe 'when disabling credential_setup' do
+      let :params do
+        default_params.merge({
+          'enable_credential_setup'   => false,
+          'credential_key_repository' => '/etc/keystone/credential-keys',
+        })
+      end
+      it { is_expected.to_not contain_file(params['credential_key_repository']) }
+      it { is_expected.to_not contain_exec('keystone-manage credential_setup') }
+    end
+  end
+
   describe 'when using fernet tokens' do
     describe 'when enabling fernet_setup' do
       let :params do
